@@ -12,7 +12,8 @@ IGNORE = ".chkbitignore"
 
 
 class Stat(Enum):
-    ERR_BITROT = "ROT"
+    ERR_DMG = "DMG"
+    ERR_BITROT = "DMG"  # legacy
     ERR_IDX = "EIX"
     WARN_OLD = "old"
     NEW = "new"
@@ -56,13 +57,25 @@ class Index:
         if self.log:
             self.log(stat, os.path.join(self.path, name))
 
-    def update(self):
+    # calc new hashes for this index
+    def update(self, context):
         for name in self.files:
             if self.should_ignore(name):
                 self._log(Stat.SKIP, name)
                 continue
-            self.new[name] = self._calc_file(name)
 
+            a = context.hash_algo
+            # check previously used hash
+            if name in self.old:
+                old = self.old[name]
+                if "md5" in old:
+                    a = "md5"  # legacy structure
+                    self.old[name] = {"mod": old["mod"], "a": a, "h": old["md5"]}
+                elif "a" in old:
+                    a = old["a"]
+            self.new[name] = self._calc_file(name, a)
+
+    # check/update the index (old vs new)
     def check_fix(self, force):
         for name in self.new.keys():
             if not name in self.old:
@@ -74,7 +87,7 @@ class Index:
             b = self.new[name]
             amod = a["mod"]
             bmod = b["mod"]
-            if a["md5"] == b["md5"]:
+            if a["h"] == b["h"]:
                 # ok, if the content stays the same the mod time does not matter
                 self._log(Stat.OK, name)
                 if amod != bmod:
@@ -82,8 +95,8 @@ class Index:
                 continue
 
             if amod == bmod:
-                # rot detected
-                self._log(Stat.ERR_BITROT, name)
+                # damage detected
+                self._log(Stat.ERR_DMG, name)
                 # replace with old so we don't loose the information on the next run
                 # unless force is set
                 if not force:
@@ -98,11 +111,11 @@ class Index:
                 self._log(Stat.WARN_OLD, name)
                 self._setmod()
 
-    def _calc_file(self, name):
+    def _calc_file(self, name, a):
         path = os.path.join(self.path, name)
         info = os.stat(path)
         mtime = int(info.st_mtime * 1000)
-        return {"mod": mtime, "md5": hashfile(path)}
+        return {"mod": mtime, "a": a, "h": hashfile(path, a)}
 
     def save(self):
         if self.modified:
@@ -111,7 +124,7 @@ class Index:
             data["idx_hash"] = hashtext(text)
 
             with open(self.idx_file, "w", encoding="utf-8") as f:
-                json.dump(data, f)
+                json.dump(data, f, separators=(",", ":"))
             self.modified = False
             return True
         else:
@@ -119,20 +132,25 @@ class Index:
 
     def load(self):
         if not os.path.exists(self.idx_file):
-            return
+            return False
         self.modified = False
         with open(self.idx_file, "r", encoding="utf-8") as f:
             data = json.load(f)
             if "data" in data:
                 # extract old format from js version
                 for item in json.loads(data["data"]):
-                    self.old[item["name"]] = {"mod": item["mod"], "md5": item["md5"]}
+                    self.old[item["name"]] = {
+                        "mod": item["mod"],
+                        "a": "md5",
+                        "h": item["md5"],
+                    }
             elif "idx" in data:
                 self.old = data["idx"]
                 text = json.dumps(self.old, separators=(",", ":"))
                 if data.get("idx_hash") != hashtext(text):
                     self.modified = True
                     self._log(Stat.ERR_IDX, self.idx_file)
+        return True
 
     def load_ignore(self):
         if not os.path.exists(self.ignore_file):
